﻿// For an introduction to the Blank template, see the following documentation:
// http://go.microsoft.com/fwlink/?LinkId=232509
(function () {
    "use strict";

    var app = WinJS.Application;
    var activation = Windows.ApplicationModel.Activation;
    var myFlipView;
    var contents;
    var myTOCData;

    app.onactivated = function (args) {
        if (args.detail.kind === activation.ActivationKind.launch) {
            if (args.detail.previousExecutionState !== activation.ApplicationExecutionState.terminated) {
                // TODO: This application has been newly launched. Initialize
                // your application here.
            } else {
                // TODO: This application has been reactivated from suspension.
                // Restore application state here.
            }
            args.setPromise(WinJS.UI.processAll().then(function () {
                var flipView = document.getElementById("basicFlipView").winControl;
                flipView.itemTemplate = mytemplate;

                flipView.itemDataSource = Data.itemList.dataSource;
            }));
        }
    };

    function mytemplate(itemPromise) {
        return itemPromise.then(function (currentItem) {
            var element = document.createElement("h2");
            element.innerText = currentItem.data.title;
            return element;
        });
    }

    //  renderTableOfContents()
    //
    //      Purpose: This function is responsible for walking through an array
    //               of titles and constructing the table of contents.
    function renderTableOfContents(dataObject, index) {

        // Step 1) Create an element to hold the table of contents.
        var TableOfContents = document.createElement("div");
        TableOfContents.className = "TableOfContents";

        // Step 2) Create an element used to center the title and items.
        var TOCCenter = document.createElement("div");
        TOCCenter.className = "TOCCenter";

        var title = document.createElement("h2");
        title.className = "TOCTitle";
        title.innerText = "Table of Contents";

        TOCCenter.appendChild(title);

        // Step 3) Loop through the elements and add them to the Table.
        for (var i = 0, len = dataObject.contents.length; i < len; i++) {
            TOCCenter.appendChild(renderTOCItem(dataObject.contents[i].title, i));
        }
        TableOfContents.appendChild(TOCCenter);

        return TableOfContents;
    }

    function renderTOCItem(itemName, itemNumber) {

        // Create the container that will hold all of the sub-elements
        var itemContainer = document.createElement("button");
        itemContainer.value = itemNumber + 1;
        itemContainer.className = "itemContainer";

        // Create a div to add some color to the item
        var lightStrip = document.createElement("div");
        lightStrip.className = "lightStrip";

        // Create a simple anchor tag to make the titles interactive,
        // store the item number so that it can be retrieved onClick,
        // add set the class name for styling, and set the visible text.
        var TOCItem = document.createElement("p");
        TOCItem.className = "TOCItem";
        TOCItem.innerText = itemName;

        // Put all the pieces together
        itemContainer.appendChild(lightStrip);
        itemContainer.appendChild(TOCItem);

        return itemContainer;
    }

    // renderItem()
    //
    //      Purpose: This function takes the raw data and constructs the
    //               item that is used in the FlipView.  It creates items of
    //               the following form:
    //
    //                  <div id="Scenario3_ItemTemplate">
    //                      <div class="overlaidItemTemplate">
    //                          <img class="image" data-win-bind="src: picture" data-win-bind="alt: title" />
    //                          <div class="overlay">
    //                              <div class="ItemTitle" data-win-bind="innerText: title"></div>
    //                          </div>
    //                      </div>
    //                  </div>
    function renderItem(dataObject) {

        // Create the Item Title div
        var itemTitle = document.createElement("h2");
        itemTitle.className = "overlayElement ItemTitle";
        itemTitle.innerText = dataObject.title;

        // Create the Item Title div
        var TOC = document.createElement("a");
        TOC.className = "overlayElement win-type-xx-small returnTOC";
        TOC.innerText = "Click to return to the Table of Contents.";

        // Create the Overlay div
        var overlay = document.createElement("div");
        overlay.className = "overlayElement overlay";
        overlay.appendChild(itemTitle);
        overlay.appendChild(TOC);

        // Create the Image div
        var image = document.createElement("img");
        image.className = "image";
        image.src = dataObject.picture;
        image.alt = dataObject.title;

        // Create the overlaidItemTemplate div
        var overlaidItemTemplate = document.createElement("div");
        overlaidItemTemplate.className = "overlaidItemTemplate";
        overlaidItemTemplate.appendChild(image);
        overlaidItemTemplate.appendChild(overlay);

        return overlaidItemTemplate;
    }

    // clickHandler
    //
    //      Purpose: This event handler is responsible for trigger navigation
    //               to the item that was clicked on in the table of contents
    //               or navigating back to the table of contents when the link
    //               is clicked on a item.
    function clickHandler(evt) {

        // First check if the source of the event is an item in the table of
        // contents
        if (WinJS.Utilities.hasClass(evt.srcElement, "itemContainer")) {

            // Since we are navigating to an item, we need to retrieve the
            // number of the page and set the currentPage on the FlipView.
            myFlipView.currentPage = parseInt(evt.srcElement.value);

        } else if (WinJS.Utilities.hasClass(evt.srcElement, "returnTOC")) {

            // Since we know that we are returning to the table of contents,
            // simply set the currentPage to trigger the navigation.
            myFlipView.currentPage = 0;
        }
    }

    app.oncheckpoint = function (args) {
        // TODO: This application is about to be suspended. Save any state
        // that needs to persist across suspensions here. You might use the
        // WinJS.Application.sessionState object, which is automatically
        // saved and restored across suspension. If you need to complete an
        // asynchronous operation before your application is suspended, call
        // args.setPromise().
    };

    app.start();
})();
